pub struct ContextError { /* private fields */ }Expand description
A custom error type to add context to the Other variant of MetadataError.
This struct wraps another error and provides additional context information.